asr.bse
=======

.. automodule:: asr.bse

   
   
   .. rubric:: Functions

   
   .. autofunction:: absorption
   .. autofunction:: get_kpts_size
   .. autofunction:: webpanel
   
   

   
   
   

   
   
   